import { defineStore } from 'pinia';
import { axiosInstance } from 'boot/axios';
import type { User } from 'components/models';

// type CreateMutable<T> = { -readonly [P in keyof T]: CreateMutable<T[P]> };

export const useUserStore = defineStore('user', {
  state: () => ({
    user: {
      loggedIn: false,
      data: {},
      dynamicRoles: [],
      sharedInfoToken: '',
    } as User,
  }),
  actions: {
    async handleLogin() {
      const useResponse = await axiosInstance.get(
        `${process.env.AUTH_API}/users/me`,
        { withCredentials: true }
      );
      this.user.data = useResponse.data;
      const rolesResponse = await axiosInstance.get(
        `${process.env.AUTH_API}/users/me/dynamic-roles`,
        { withCredentials: true }
      );
      this.user.dynamicRoles = rolesResponse.data;
      const sharedInfoTokenResponse = await axiosInstance.get(
        `${process.env.AUTH_API}/users/me/shared-info-token`,
        { withCredentials: true }
      );
      this.user.sharedInfoToken = sharedInfoTokenResponse.data;
      this.user.loggedIn = true;
    },
  },
  getters: {
    userHSEEmail(state) {
      return state.user.data?.['hse_email'];
    },
    userGoogleEmail(state) {
      return state.user.data?.['google_email'];
    },

    userFullName(state): string {
      return state.user.data?.['name']?.['full_name'];
    },

    userNameAbbr(state) {
      const fn: string = state.user.data?.['name']?.[
        'first_name'
      ]?.[0] as unknown as string;
      const ln: string = state.user.data?.['name']?.[
        'last_name'
      ]?.[0] as unknown as string;
      return fn + ln;
    },

    thumbnailPhotoUrl(state) {
      return state.user.data?.['google_data']?.['thumbnailPhotoUrl'];
    },

    isStudent(state): boolean {
      return state.user.dynamicRoles?.includes('STUDENT');
    },

    isLecturer(state): boolean {
      return state.user.dynamicRoles?.includes('LECTURER');
    },

    isSuperAdmin(state): boolean {
      const roles: Array<string> = state.user.data?.['roles'] as unknown as Array<string>;
      return roles.includes('SUPER_ADMIN') ?? false;
    },

    isDeveloper(state): boolean {
      const roles: Array<string> = state.user.data?.['roles'] as unknown as Array<string>;
      return roles.includes('DEVELOPER') ?? false;
    },
    ruzGroup(state) {
      return state.user.data?.['ruz_data']?.['group'];
    },
    ruzDepartment(state) {
      return state.user.data?.['ruz_data']?.['department'];
    },

    roles(state) {
      return state.user.data?.['roles'] ?? [];
    },

    dynamicRoles(state) {
      return state.user.dynamicRoles ?? [];
    },

    authToken(state): string {
      return state.user.data?.['auth_token'] as unknown as string;
    },
  },
});
